=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2007-03-09 04:02:35 +0000
+++ bzrlib/errors.py	2007-03-11 00:47:07 +0000
@@ -1867,6 +1867,12 @@
         self.name = name
 
 
+class NotAMergeDirective(BzrError):
+    """File starting with %(firstline)r is not a merge directive"""
+    def __init__(self, firstline):
+        BzrError.__init__(self, firstline=firstline)
+
+
 class NoMergeSource(BzrError):
     """Raise if no merge source was specified for a merge directive"""
 

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2007-03-09 21:51:41 +0000
+++ bzrlib/merge_directive.py	2007-03-11 00:47:07 +0000
@@ -88,7 +88,8 @@
         :param lines: An iterable of lines
         :return: a MergeRequest
         """
-        assert lines[0].startswith('# ' + klass._format_string + '\n')
+        if not lines[0].startswith('# ' + klass._format_string):
+            raise errors.NotAMergeDirective(lines[0])
         line_iter = iter(lines[1:])
         stanza = rio.read_patch_stanza(line_iter)
         patch_lines = list(line_iter)

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- bzrlib/tests/test_merge_directive.py	2007-03-09 21:51:41 +0000
+++ bzrlib/tests/test_merge_directive.py	2007-03-11 00:47:07 +0000
@@ -85,6 +85,11 @@
             patch='booga', patch_type='diff', message="Hi mom!")
         self.assertEqualDiff(OUTPUT2, ''.join(md.to_lines()))
 
+    def test_deserialize_junk(self):
+        self.assertRaises(errors.NotAMergeDirective,
+                          merge_directive.MergeDirective.from_lines, 'lala')
+
+
     def test_roundtrip(self):
         time = 501
         timezone = 72

